Crate lex_sleuther

Crate lex_sleuther 

Re-exports

pub use ndarray;

Modules

lex
regression

Structs

Classification
A list of verdicts in descending order of likelyhood.
Model
A model capable of producing Classifications from files or bytes.
Verdict
The score and probability returned for each class label.

Functions

baked_model
Returns the model prebaked into the library with the baked_model feature