Re-exports
pub use ndarray;
Modules
Structs
- Classification
- A list of verdicts in descending order of likelyhood.
- Model
- A model capable of producing Classifications from files or bytes.
- Verdict
- The score and probability returned for each class label.
Functions
- baked_
model - Returns the model prebaked into the library with the
baked_modelfeature